use std::path::{Path, PathBuf};

use clap::Parser;

use crate::constants::USERS_LIST_FILE;

/// Basic OIDC provider
#[derive(Parser, Debug)]
#[clap(author, version, about, long_about = None)]
pub struct AppConfig {
    /// Listen address
    #[clap(short, long, env, default_value = "0.0.0.0:8000")]
    pub listen_address: String,

    /// Storage path
    #[clap(short, long, env)]
    pub storage_path: String,

    /// App token token
    #[clap(short, long, env, default_value = "")]
    pub token_key: String,

    /// Should the auth cookie be secure
    #[clap(long, env)]
    pub secure_auth_cookie: bool,
}

impl AppConfig {
    pub fn storage_path(&self) -> &Path {
        self.storage_path.as_ref()
    }

    pub fn users_file(&self) -> PathBuf {
        self.storage_path().join(USERS_LIST_FILE)
    }
}